#/bin/bash

###OS ROSA 12.5.1
###Откройте папку, в которой находится скрипт, и запустите терминал
###Сделайте файл исполняемым командой chmod ugo+x PHP-8.3.11.sh
###Запустите скрипт командой ./PHP-8.3.11.sh
###(Для обновления версии PHP) текущую версию смотрите на https://www.php.net/downloads
###Или поменяйте ссылку с https://github.com/php/php-src/tags
###Скрипт устанавливает PHP в папку /opt/php, а не разбрасывает PHP по всей /usr, так что удалить PHP можно просто удалив лишь одну папку и выполнить sudo dnf remove -y apache-base; sudo dnf -y install apache-base; sudo dnf -y install apache-mod_php;  sudo systemctl restart httpd; sudo systemctl restart httpd; sudo systemctl enable httpd

###Подготовьте окружающую среду
cd /tmp && curl -LO https://www.php.net/distributions/php-8.3.11.tar.gz
tar -xvf php*.tar.gz && cd php-8.3.11 ###Для zip архива используйте unzip, для архива tar.gz используйте tar -xvf


###Установите программные библиотеки, от которых зависит PHP при компиляции
#sudo dnf update
sudo dnf install -y lib64openssl-devel lib64curl-devel lib64png-devel lib64webp-devel lib64jpeg-devel lib64freetype6-devel gcc make nginx lib64zip-devel apache-base bison re2c autoconf gcc-c++ lib64pq++-devel lib64xslt-devel lib64xml2-devel lib64sqlite3-devel php-pgsql php-pdo postgresql16-server postgresql16-contrib postgresql16-devel lib64onig5 lib64onig-devel  php-mysql apache-mod_php apache-devel php php-cli
export PKG_CONFIG_PATH=/usr/lib64/pkgconfig

#./buildconf --force ###Требуется только при сборке из github для создания configure

###Настройка функций (модули)
./configure --prefix=/opt/php \
--enable-fpm --with-openssl --with-zlib --with-curl --enable-gd --with-webp \
--with-jpeg --with-freetype --enable-mbstring --with-zip --with-mysqli \
--with-pdo-mysql --with-pgsql --with-apxs2 --with-pear --with-pdo-pgsql

###Выполнить компиляцию и установку (Чтобы ускорить процесс, вы можете указать количество ядер, определенных командой nproc и использовать вместо команды make команду make -jN, где N - количество ядер)
nproc
make -j$(nproc)
sudo make install


###Настройка PHP
sudo mkdir /run/php-fpm
echo 'export PATH="/opt/php/bin:$PATH"' >> ~/.bashrc
source ~/.bashrc
sudo cp php.ini-production /opt/php/lib/php.ini
sudo cp /opt/php/etc/php-fpm.conf.default /opt/php/etc/php-fpm.conf
sudo cp /opt/php/etc/php-fpm.d/www.conf.default /opt/php/etc/php-fpm.d/www.conf

###Увеличить максимальный размер загружаемого файла и максимальный размер публикации для сайта WordPress
sudo sed -i 's/upload_max_filesize = 2M/upload_max_filesize = 64M/g' /opt/php/lib/php.ini
sudo sed -i 's/post_max_size = 8M/post_max_size = 64M/g' /opt/php/lib/php.ini

###Как правило, у нас есть учетная запись пользователя / группы, имя которой apache (если установлен apache) настраивается из программы веб-сервера (Nginx). Мы изменим значения двух директив user и group, которые в основном представляют собой имя пользователя и группу пользователей владельца веб-файлов
sudo sed -i 's/user = nobody/user = apache/g' /opt/php/etc/php-fpm.d/www.conf
sudo sed -i 's/group = nobody/group = apache/g' /opt/php/etc/php-fpm.d/www.conf
#sudo sed -i 's/user = nobody/user = nginx/g' /opt/php/etc/php-fpm.d/www.conf
#sudo sed -i 's/group = nobody/group = nginx/g' /opt/php/etc/php-fpm.d/www.conf

###Чтобы веб-сервер взаимодействовал с FPM через файл сокета, нужно установить каталог файла сокета для прослушивания директивы, чтобы FPM мог выполнять запись
sudo sed -i 's/listen = 127.0.0.1:9000/listen =\/run\/php-fpm\/www.sock/g' /opt/php/etc/php-fpm.d/www.conf

###Установить разрешение файла сокета, чтобы веб-сервер мог читать
sudo sed -i 's/;listen.owner = nobody/listen.owner = apache/g' /opt/php/etc/php-fpm.d/www.conf
sudo sed -i 's/;listen.group = nobody/listen.group = apache/g' /opt/php/etc/php-fpm.d/www.conf
#sudo sed -i 's/;listen.owner = nobody/listen.owner = nginx/g' /opt/php/etc/php-fpm.d/www.conf
#sudo sed -i 's/;listen.group = nobody/listen.group = nginx/g' /opt/php/etc/php-fpm.d/www.conf


####Создать службу php-fpm
sudo bash -c 'cat > /etc/systemd/system/php-fpm.service' <<EOF
# BEGIN
[Unit]
Description=PHP FastCGI process manager
After=local-fs.target network.target nginx.service

[Service]
Type=forking
RuntimeDirectory=php-fpm
RuntimeDirectoryMode=0755
ExecStart=/opt/php/sbin/php-fpm
ExecReload=/bin/kill -USR2 \$MAINPID

[Install]
WantedBy=multi-user.target
# END
EOF

###Запустить службы
sudo systemctl daemon-reload
sudo systemctl start php-fpm && sudo systemctl enable php-fpm
#sudo systemctl start nginx && sudo systemctl enable nginx
sudo systemctl start httpd && sudo systemctl enable httpd && sudo systemctl restart httpd
sudo systemctl start postgresql16 && sudo systemctl enable postgresql16


###Модули
php -m
###Проверить версию PHP в терминале
php -v
###После изменения конфигурации вы можете запустить приведенную ниже команду для тестирования. Если вы видите слово "test is successful", это означает, что конфигурация подходит для запуска FPM
sudo /opt/php/sbin/php-fpm -t
###Определить, какой PHP используется
which php
###Созданиее файла для проверки PHP в браузере
sudo bash -c 'cat > /var/www/html/info_version.php' <<EOF
<?php phpinfo(); ?>
EOF
	echo "Нажмите на ссылку (удерживая Ctrl) для проверки http://localhost/info_version.php"
